This is a model agnostic resampling class, where Rademacher random variables are used to add or substract the residuals from the fitted values.
new()GOF_sim_wild_rademacher$new(gof_model_info_extractor)gof_model_info_extractorthe info extractor that is used to derive the residuals and fitted values for resampling.
resample_y()a wild bootstrap using Rademacher random variables to resample the dependent variable
GOF_sim_wild_rademacher$resample_y(model)modelsee GOF_model_simulator
see GOF_model_simulator
clone()The objects of this class are cloneable with this method.
GOF_sim_wild_rademacher$clone(deep = FALSE)deepWhether to make a deep clone.